@@ -7,9 +7,9 @@ Python ``@deprecated`` decorator to deprecate old python classes, functions or m
 
 """
 
-__version__ = "1.2.13"
+__version__ = "1.2.14"
 __author__ = u"Laurent LAPORTE <tantale.solutions@gmail.com>"
-__date__ = "2021-09-05"
+__date__ = "unreleased"
 __credits__ = "(c) Laurent LAPORTE"
 
 from deprecated.classic import deprecated
